@@ -144,10 +144,12 @@ namespace types
   {
     return value;
   }
-  template <long N>
+
+  template <long N, long P>
   std::integral_constant<long, N> check_type(std::integral_constant<long, N>,
-                                             std::integral_constant<long, N>)
+                                             std::integral_constant<long, P>)
   {
+    assert(N == P && "consistent init");
     return {};
   }
   template <long N>
@@ -805,15 +807,29 @@ struct __combined<container<t>, std::tuple<t0...>> {
   using type = std::tuple<t0...>;
 };
 
+PYTHONIC_NS_BEGIN
+namespace details
+{
+  template <class T, class P, bool Same>
+  struct pick_combined;
+  template <class T, class P>
+  struct pick_combined<T, P, true> {
+    using type = typename __combined<T, P>::type;
+  };
+  template <class T, class P>
+  struct pick_combined<T, P, false> {
+    using type = P;
+  };
+}
+PYTHONIC_NS_END
+
 template <long I, class t, class... t0>
 struct __combined<std::tuple<t0...>,
                   indexable_container<std::integral_constant<long, I>, t>> {
   using holder = std::tuple<t0...>;
   template <size_t... Is>
-  static std::tuple<typename std::conditional<
-      I == Is, typename __combined<
-                   t, typename std::tuple_element<Is, holder>::type>::type,
-      typename std::tuple_element<Is, holder>::type>::type...>
+  static std::tuple<typename pythonic::details::pick_combined<
+      t, typename std::tuple_element<Is, holder>::type, I == Is>::type...>
       make_type(pythonic::utils::index_sequence<Is...>);
   static auto make_type() -> decltype(
       make_type(pythonic::utils::make_index_sequence<sizeof...(t0)>()));
@@ -907,9 +923,8 @@ namespace std
   }
 
   template <class... Tys>
-  class tuple_size<pythonic::types::pshape<Tys...>>
-      : public std::integral_constant<std::size_t, sizeof...(Tys)>
-  {
+  struct tuple_size<pythonic::types::pshape<Tys...>>
+      : public std::integral_constant<std::size_t, sizeof...(Tys)> {
   };
 
   template <size_t I, class... Tys>
@@ -1051,13 +1066,13 @@ namespace sutils
   template <class T0, T0 N, class T1>
   void assign(std::integral_constant<T0, N> &t0, T1 t1)
   {
-    assert(t0 == t1 && "consistent");
+    assert((long)t0 == (long)t1 && "consistent");
   }
 
   template <size_t Start, ssize_t Offset, class T0, class T1, size_t... Is>
   void copy_shape(T0 &shape0, T1 const &shape1, utils::index_sequence<Is...>)
   {
-    std::initializer_list<int> _ = {
+    (void)std::initializer_list<int>{
         (assign(std::get<Start + Is>(shape0),
                 shape1.template shape<Is + Start + Offset>()),
          1)...};
@@ -1065,7 +1080,7 @@ namespace sutils
   template <size_t Start, ssize_t Offset, class T0, class T1, size_t... Is>
   void scopy_shape(T0 &shape0, T1 const &shape1, utils::index_sequence<Is...>)
   {
-    std::initializer_list<int> _ = {
+    (void)std::initializer_list<int>{
         (assign(std::get<Start + Is>(shape0),
                 std::get<Is + Start + Offset>(shape1)),
          1)...};
@@ -1074,7 +1089,7 @@ namespace sutils
   void copy_strides(T0 &stride0, T1 const &stride1,
                     utils::index_sequence<Is...>)
   {
-    std::initializer_list<int> _ = {
+    (void)std::initializer_list<int>{
         (assign(std::get<Start + Is>(stride0),
                 stride1.template strides<Is + Start + Offset>()),
          1)...};
@@ -1226,8 +1241,8 @@ namespace sutils
   long sfind(S &s, long v, std::integral_constant<size_t, I>, long start,
              bool comp(long, long))
   {
-    return comp(std::get<I>(s), v) && I < start
-               ? I
+    return comp(std::get<I>(s), v) && (long)I < start
+               ? (long)I
                : sfind(s, v, std::integral_constant<size_t, I - 1>(), start,
                        comp);
   }
