@@ -77,7 +77,7 @@ namespace types
   {
     array<long, std::tuple_size<pS>::value> out;
     out[std::tuple_size<pS>::value - 1] = 1;
-    std::initializer_list<long> _ = {
+    (void)std::initializer_list<long>{
         (out[std::tuple_size<pS>::value - Is - 2] =
              out[std::tuple_size<pS>::value - Is - 1] *
              std::get<std::tuple_size<pS>::value - Is - 1>(shape))...};
@@ -388,6 +388,16 @@ namespace types
     std::copy(other.fbegin(), other.fend(), fbegin());
   }
 
+  template <class T, class pS>
+  template <class pSp>
+  ndarray<T, pS>::ndarray(ndarray<T, pSp> const &other)
+      : mem(other.mem), buffer(mem->data), _shape(other._shape),
+        _strides(other._strides)
+  {
+    static_assert(std::tuple_size<pS>::value == std::tuple_size<pSp>::value,
+                  "compatible shapes");
+  }
+
   /* from a seed */
   template <class T, class pS>
   ndarray<T, pS>::ndarray(pS const &shape, none_type init)
@@ -679,7 +689,7 @@ namespace types
   template <class vectorizer>
   typename ndarray<T, pS>::simd_iterator ndarray<T, pS>::vend(vectorizer) const
   {
-    using vector_type = typename xsimd::simd_type<dtype>;
+    using vector_type = typename xsimd::batch<dtype>;
     static const std::size_t vector_size = vector_type::size;
     return {buffer + long(std::get<0>(_shape) / vector_size * vector_size)};
   }
@@ -1526,18 +1536,21 @@ bool from_python<types::ndarray<T, pS>>::is_convertible(PyObject *obj)
   auto const *stride = PyArray_STRIDES(arr);
   auto const *dims = PyArray_DIMS(arr);
   long current_stride = PyArray_ITEMSIZE(arr);
-  for (long i = std::tuple_size<pS>::value - 1; i >= 0; i--) {
-    if (stride[i] == 0 && dims[i] == 1) {
-      // happens when a new dim is added though None/newaxis
-    } else if (stride[i] != current_stride)
+  if (PyArray_SIZE(arr)) {
+    for (long i = std::tuple_size<pS>::value - 1; i >= 0; i--) {
+      if (stride[i] == 0 && dims[i] == 1) {
+        // happens when a new dim is added though None/newaxis
+      } else if (stride[i] != current_stride && dims[i] > 1) {
+        return false;
+      }
+      current_stride *= dims[i];
+    }
+    // this is supposed to be a texpr
+    if ((PyArray_FLAGS(arr) & NPY_ARRAY_F_CONTIGUOUS) &&
+        ((PyArray_FLAGS(arr) & NPY_ARRAY_C_CONTIGUOUS) == 0) &&
+        (std::tuple_size<pS>::value > 1)) {
       return false;
-    current_stride *= dims[i];
-  }
-  // this is supposed to be a texpr
-  if ((PyArray_FLAGS(arr) & NPY_ARRAY_F_CONTIGUOUS) &&
-      ((PyArray_FLAGS(arr) & NPY_ARRAY_C_CONTIGUOUS) == 0) &&
-      (std::tuple_size<pS>::value > 1)) {
-    return false;
+    }
   }
 
   // check if dimension size match
